homology.dim0 — GDA Toolbox v1.0 Manual

# homology.dim0

This Cython module contains the core algorithms for 0-dimension topological algorithms. In particular, MergeTree for 0-dimensional persistence.

If a function requires its own explicit iterator in a loop, probably it should go here. Anything that is just a vectorized operation in NumPy or Pandas can go in plain python elsewhere.

See http://docs.cython.org/src/tutorial/np.html for ideas on writing efficient code in Cython.

This module is compiled by either of these commands
  - `python setup.py install` (as called by `pip` for standard installation and use)
  - `python setup.py build_ext --inplace` (as run by developers for code testing)

## Notes

Automatically-generated online documentation will never see the C-only functions that are defined with `cdef` in Cython, as shown in http://cython.readthedocs.io/en/latest/src/reference/extension_types.html Because of the limitations of Sphinx, you’ll have to simply view the sourcecode for further information. For this module, these C-only functions include

> - `homology.dim0.root()`
> - `homology.dim0.connected()`
> - `homology.dim0.merge()`

## Copyright

- This file is part of https://github.com/geomdata/gda-public/
- 2015, 2016, 2017 by Geometric Data Analytics, Inc. (http://geomdata.com)
- AGPL license. See LICENSE or https://github.com/geomdata/gda-public/blob/master/LICENSE

Functions

`all_roots` | Reference each vertex directly to its representative root, from MergeTree.
`mkforestDBL` | Make inclusion tree and parentage linked lists by walking across This method is for `np.float64` arrays (for indexing speed).
`unionfind` | Apply the UnionFind algorithm to compute zero-dimensional persistence diagram.

### Table of Contents

- homology.dim0
  - Notes
  - Copyright

#### Previous topic

timeseries.curve_geometry

#### Next topic

homology.dim1